package com.chelvc.cloud.vehicle.server.entity;

import java.util.Date;
import java.util.List;

import com.baomidou.mybatisplus.annotation.IdType;
import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableId;
import com.baomidou.mybatisplus.annotation.TableName;
import com.chelvc.cloud.vehicle.api.constant.CouponClaimType;
import com.chelvc.cloud.vehicle.api.constant.CouponRangeDay;
import com.chelvc.cloud.vehicle.api.constant.CouponStatus;
import com.chelvc.cloud.vehicle.api.constant.CouponType;
import com.chelvc.cloud.vehicle.api.constant.PromotionScopeType;
import com.chelvc.cloud.vehicle.api.constant.PromotionStatus;
import com.chelvc.framework.database.entity.ModifyEntity;
import lombok.AllArgsConstructor;
import lombok.Data;
import lombok.EqualsAndHashCode;
import lombok.NoArgsConstructor;
import lombok.ToString;
import lombok.experimental.SuperBuilder;

/**
 * 优惠券数据模型
 *
 * @author Woody
 * @date 2023/7/17
 */
@Data
@SuperBuilder
@NoArgsConstructor
@AllArgsConstructor
@ToString(callSuper = true)
@EqualsAndHashCode(callSuper = true)
@TableName(autoResultMap = true)
public class Coupon extends BasePromotion {

    /**
     * 优惠券类型
     */
    private CouponType type;

    /**
     * 优惠券名称
     */
    private String name;

    /**
     * 优惠金额
     */
    private Double amount;

    /**
     * 满减金额
     */
    private Double reduce;

    /**
     * 优惠折扣
     */
    private Double discount;

    /**
     * 过期时间
     */
    private Date expiration;

    /**
     * 优惠券描述
     */
    private String description;

    /**
     * 优惠券状态
     */
    private CouponStatus status;

    /**
     * 限制领取数量
     */
    private Integer limitNum;

    /**
     * 发行数量
     */
    private Integer publishNum;

    /**
     * 已被领取的数量
     */
    private Integer receivedNum;

    /**
     * 已被使用的数量
     */
    private Integer usedNum;

    /**
     * 优惠券获取方式类型
     */
    private CouponClaimType claimType;

    /**
     * 时间范围类型
     */
    private CouponRangeDay rangeDayType;

    /**
     * 有效天数
     */
    private Integer effectiveDays;

    /**
     * 关联范围类型
     */
    private PromotionScopeType scopeType = PromotionScopeType.ALL;

    /**
     * 范围关联的id
     */
    private String scopeId;

    /**
     * 促销状态
     */
    @TableField(exist = false)
    private PromotionStatus promotionStatus;

    /**
     * 优惠券关联商品集合
     */
    @TableField(exist = false)
    private List<PromotionGoods> promotionGoodsList;
}
