package com.chelvc.cloud.vehicle.server.entity;

import cn.hutool.core.date.DateField;
import cn.hutool.core.date.DateTime;
import cn.hutool.core.date.DateUtil;
import com.baomidou.mybatisplus.annotation.IdType;
import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableId;
import com.chelvc.cloud.vehicle.api.constant.CouponClaimType;
import com.chelvc.cloud.vehicle.api.constant.CouponType;
import com.chelvc.cloud.vehicle.api.constant.PromotionScopeType;
import com.chelvc.cloud.vehicle.api.constant.UserCouponStatus;
import com.chelvc.framework.database.entity.ModifyEntity;
import com.fasterxml.jackson.annotation.JsonFormat;
import lombok.AllArgsConstructor;
import lombok.Data;
import lombok.EqualsAndHashCode;
import lombok.NoArgsConstructor;
import lombok.ToString;
import lombok.experimental.SuperBuilder;

import java.util.Date;

/**
 * 优惠券领取数据模型
 *
 * @author Woody
 * @date 2023/7/17
 */
@Data
@SuperBuilder
@NoArgsConstructor
@AllArgsConstructor
@ToString(callSuper = true)
@EqualsAndHashCode(callSuper = true)
public class UserCoupon extends ModifyEntity<Long> {
    /**
     * 主键
     */
    @TableId(type = IdType.AUTO)
    private Long id;

    /**
     * 用户ID
     */
    private Long userId;

    /**
     * 优惠券ID
     */
    private Long couponId;

    /**
     * 优惠券类型
     */
    private CouponType type;

    /**
     * 是否已使用
     */
    private Boolean used;

    /**
     * 优惠券
     */
    @TableField(exist = false)
    private Coupon coupon;

    /**
     * 商家ID
     */
    private String merchantId;

    /**
     * 商家名称
     */
    private String merchantName;

    /**
     * 面额
     */
    private Double price;

    /**
     * 折扣
     */
    private Double discount;

    /**
     * 消费门槛
     */
    private Double consumeThreshold;

    /**
     * 用户名称
     */
    private String userName;

    /**
     * 关联范围类型
     */
    private PromotionScopeType scopeType;

    /**
     * 优惠券类型
     */
    private CouponType couponType;

    /**
     * 范围关联的ID
     */
    private String scopeId;

    /**
     * 使用起始时间
     */
    private Date startTime;

    /**
     * 使用截止时间
     */
    private Date endTime;

    /**
     * 优惠券类型，分为免费领取和活动赠送
     */
    private CouponClaimType claimType;

    /**
     * 是否是平台优惠券
     */
    private Boolean platformFlag;

    /**
     * 店铺承担比例
     */
    private Double storeCommission;

    /**
     * 核销时间
     */
    private Date consumptionTime;

    /**
     * 用户优惠券状态
     */
    private UserCouponStatus userCouponStatus;
}
